import * as vscode from 'vscode';
import { paramCase } from './promiseLinesHelper';

async function updateWithLogic(textDocument: vscode.TextDocument) {
    await vscode.window.showTextDocument(textDocument);
    const textEditor = vscode.window.activeTextEditor;
    if (!textEditor) {
        return undefined;
    }
    const now: Date = new Date();
    const time: number = now.getTime();
    const year: number = now.getFullYear();
    const start: Date = new Date(year, 0, 0);
    const oneDay: number = 1000 * 60 * 60 * 24;
    const timezoneOffset: number = now.getTimezoneOffset();
    let segments: string[] = textDocument.fileName.split('\\');
    const diff: number = (time - start.getTime()) + ((start.getTimezoneOffset() - timezoneOffset) * 60 * 1000);
    const day: number = Math.floor(diff / oneDay);
    const seconds: number = time.valueOf() + timezoneOffset;
    let notLastThree: string[] = segments.slice(0, -3);
    let season: string = year + "-";
    if (day < 78) {
        season += "0.Winter";
    } else if (day < 124) {
        season += "1.Spring";
    } else if (day < 171) {
        season += "2.Spring";
    } else if (day < 217) {
        season += "3.Summer";
    } else if (day < 264) {
        season += "4.Summer";
    } else if (day < 309) {
        season += "5.Fall";
    } else if (day < 354) {
        season += "6.Fall";
    } else {
        season += "7.Winter";
    }
    let path: string = notLastThree.join('\\') + `\\${year}\\${season}\\${seconds}`;
    const uri = vscode.Uri.parse(path);
    textEditor.edit(editBuilder => {
        let text: string = `\r\n## Code Insiders\r\n\r\n- [code-insiders](${path})\r\n\r\n## Sub-tasks\r\n\r\n- [ ] To do`;
        let position: vscode.Position = new vscode.Position(textDocument.lineCount, 0);
        editBuilder.insert(position, text);
    });
}

async function openInNewWindowLogic(): Promise<any> {
    if (vscode.workspace.workspaceFolders === undefined) {
        vscode.window.showInformationMessage("Open workspace first!");
        return;
    }
    if (vscode.window.tabGroups.activeTabGroup.activeTab === undefined) {
        vscode.window.showInformationMessage("Open a tab first!");
        return;
    }
    const activeTab = vscode.window.tabGroups.activeTabGroup.activeTab;
    const tabs: vscode.Tab[] = vscode.window.tabGroups.all.map(tagGroup => tagGroup.tabs).flat();
    const index = tabs.findIndex(tab => tab.label === activeTab.label);
    const paramCaseActiveTabLabel: string = paramCase(activeTab.label);
    vscode.window.showInformationMessage(`Searching for <${paramCaseActiveTabLabel}>`);
    const fileUris: vscode.Uri[] = await vscode.workspace.findFiles(`**/${paramCaseActiveTabLabel}*`);
    if (fileUris.length === 0) {
        vscode.window.showInformationMessage(`Didn't find a file matching <${paramCaseActiveTabLabel}>!`);
        return;
    }
    for (let i = 0; i < fileUris.length; ++i) {
        let found: boolean = false;
        const textDocument: vscode.TextDocument = await vscode.workspace.openTextDocument(fileUris[i]);
        for (let j = 0; j < textDocument.lineCount; ++j) {
            const text = textDocument.lineAt(j).text;
            if (text.endsWith(')')) {
                if (text.startsWith("- [code](")) {
                    found = true;
                    const uri = vscode.Uri.parse("file:" + text.substring(9, text.length - 1));
                    await vscode.commands.executeCommand('vscode.openFolder', uri, true);
                    break;
                }
                if (text.startsWith("- [codium](")) {
                    found = true;
                    const uri = vscode.Uri.parse("file:" + text.substring(11, text.length - 1));
                    await vscode.commands.executeCommand('vscode.openFolder', uri, true);
                    break;
                }
                if (text.startsWith("- [code-insiders](")) {
                    found = true;
                    const uri = vscode.Uri.parse("file:" + text.substring(18, text.length - 1));
                    await vscode.commands.executeCommand('vscode.openFolder', uri, true);
                    break;
                }
            }
        }
        if (!found) {
            updateWithLogic(textDocument);
        }
        else if (index !== -1) {
            await vscode.window.tabGroups.close(tabs[index]);
        }
    }
}

async function openWithTextEditorLogic(): Promise<any> {
    if (vscode.workspace.workspaceFolders === undefined) {
        vscode.window.showInformationMessage("Open workspace first!");
        return;
    }
    if (vscode.window.tabGroups.activeTabGroup.activeTab === undefined) {
        vscode.window.showInformationMessage("Open a tab first!");
        return;
    }
    const activeTabLabel = vscode.window.tabGroups.activeTabGroup.activeTab.label;
    const paramCaseActiveTabLabel: string = paramCase(activeTabLabel);
    vscode.window.showInformationMessage(`Searching for <${paramCaseActiveTabLabel}>`);
    const fileUris: vscode.Uri[] = await vscode.workspace.findFiles(`**/${paramCaseActiveTabLabel}*`);
    if (fileUris.length === 0) {
        vscode.window.showInformationMessage(`Didn't find a file matching <${paramCaseActiveTabLabel}>!`);
        return;
    }
    for (let i = 0; i < fileUris.length; ++i) {
        const textDocument: vscode.TextDocument = await vscode.workspace.openTextDocument(fileUris[i]);
        await vscode.window.showTextDocument(textDocument);
    }
}

export const openInNewWindow = () => openInNewWindowLogic();
export const openWithTextEditor = () => openWithTextEditorLogic();